diff src/evalvars.c @ 23509:18f3dc6974af v8.2.2297

patch 8.2.2297: Vim9: cannot set 'number' to a boolean value Commit: https://github.com/vim/vim/commit/0ea04408653be843e37d03ce574f5d2eae682339 Author: Bram Moolenaar <Bram@vim.org> Date: Mon Jan 4 13:37:54 2021 +0100 patch 8.2.2297: Vim9: cannot set 'number' to a boolean value Problem: Vim9: cannot set 'number' to a boolean value. Solution: Use tv_get_bool(). (closes https://github.com/vim/vim/issues/7615)
author Bram Moolenaar <Bram@vim.org>
date Mon, 04 Jan 2021 13:45:04 +0100
parents 2247a2ce3630
children 27ca5534a408
line wrap: on
line diff
--- a/src/evalvars.c
+++ b/src/evalvars.c
@@ -1370,8 +1370,14 @@ ex_let_one(
 			|| opt_type == gov_hidden_bool
 			|| opt_type == gov_hidden_number)
 			     && (tv->v_type != VAR_STRING || !in_vim9script()))
-		// number, possibly hidden
-		n = (long)tv_get_number(tv);
+	    {
+		if (opt_type == gov_bool || opt_type == gov_hidden_bool)
+		    // bool, possibly hidden
+		    n = (long)tv_get_bool(tv);
+		else
+		    // number, possibly hidden
+		    n = (long)tv_get_number(tv);
+	    }
 
 	    // Avoid setting a string option to the text "v:false" or similar.
 	    // In Vim9 script also don't convert a number to string.